﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CsFileCopy
{
    /// <summary>
    /// CsFileCopyのオプションダイアログです。
    /// </summary>
    public partial class OptionDialog : Form
    {
        /// <summary>
        /// メインウィンドウ
        /// </summary>
        private MainWindow parent;

        /// <summary>
        /// オプションダイアログを作成します。
        /// </summary>
        /// <param name="parent">メインウィンドウ</param>
        public OptionDialog(MainWindow parent)
        {
            InitializeComponent();
            this.parent = parent;
        }

        /// <summary>
        /// ウィンドウロード時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void OptionDialog_Load(object sender, EventArgs e)
        {
            ApplicationSettings appSetting = parent.AppSettings;

            // 大文字小文字を区別する場合
            if (appSetting.CenseCaseRadioChecked)
            {
                censeCaseRadioButton.Checked = true;
                ignoreCaseRadioButton.Checked = false;
            }
            // 大文字小文字を区別しない場合
            if (appSetting.IgnoreCaseRadioChecked)
            {
                ignoreCaseRadioButton.Checked = true;
                censeCaseRadioButton.Checked = false;
            }

            okButton.Select();
        }

        /// <summary>
        /// OKボタンがクリックされた時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e"イベント></param>
        private void okButton_Click(object sender, EventArgs e)
        {
            ApplicationSettings appSetting = parent.AppSettings;

            // 大文字小文字を区別するが選択された場合
            if (censeCaseRadioButton.Checked)
            {
                appSetting.CenseCaseRadioChecked = true;
                appSetting.IgnoreCaseRadioChecked = false;
            }
            // 大文字小文字を区別しないが選択された場合
            if (ignoreCaseRadioButton.Checked)
            {
                appSetting.IgnoreCaseRadioChecked = true;
                appSetting.CenseCaseRadioChecked = false;
            }

            Close();
        }

        /// <summary>
        /// キャンセルボタンがクリックされた時の処理です。
        /// </summary>
        /// <param name="sender">イベントを発生させたオブジェクト</param>
        /// <param name="e">イベント</param>
        private void cancelButton_Click(object sender, EventArgs e)
        {
            Close();
        }
    }
}
